PackedU8

Struct PackedU8 

#[repr(transparent)]
pub struct PackedU8(u8);

Tuple Fields

0: u8

Implementations

Source

impl PackedU8

pub fn get(self, start: u8, bits: u8) -> u8

Get bits bits starting from bit start

pub fn set(&mut self, start: u8, bits: u8, value: u8)

Set bits bits starting from bit start to value value will be shortened to bits bits to avoid overwriting other data